Creates up to 10 records per API call. If more than 10 records are provided, they are automatically batched.
Usage
at_create_records(
base_id,
table_id,
records,
typecast = FALSE,
token = NULL,
progress = NULL
)Arguments
- base_id
Base ID (e.g.,
"appXXXXXX").- table_id
Table name or ID.
- records
A list of record objects. Each should be a list with a
fieldselement (a named list of field values).- typecast
If
TRUE, Airtable will attempt to cast values to the correct type.- token
Personal access token (resolved via
air_token()ifNULL).- progress
Logical or
NULL. IfTRUE, shows a cli progress bar for batch operations. IfNULL(default), uses optionairtable2.progress.baror env varAIRTABLE2_PROGRESS_BAR(both default toFALSE).